==> deepin-fcitx5configtool-plugin_6.0.8.tar.xz: BUILD/src/dcc-fcitx5configtool/translations/fcitx5configtool_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>AddonsPage</name>
    <message>
        <location filename="../qml/AddonsPage.qml" line="20"/>
        <source>Add-ons</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AdvancedSettingsModule</name>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="14"/>
        <source>Advanced Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="28"/>
        <source>&quot;Advanced Settings&quot; is only valid for the input method that uses the system settings, if the input method has its own settings, its own settings shall prevail.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="41"/>
        <source>Global Config</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="52"/>
        <source>Add-ons</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DetailConfigItem</name>
    <message>
        <location filename="../qml/DetailConfigItem.qml" line="126"/>
        <source>Please enter a new shortcut</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>IMList</name>
    <message>
        <location filename="../qml/IMList.qml" line="54"/>
        <source>Move Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="61"/>
        <source>Move Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="69"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="76"/>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>InputMethodsChooser</name>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="29"/>
        <source>Add input method</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="37"/>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="102"/>
        <source>Find more in App Store</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="121"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="128"/>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ManageInputMethodsModule</name>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="15"/>
        <source>Input method management</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="29"/>
        <source>Add input method</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShortcutsModule</name>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="34"/>
        <source>Shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="45"/>
        <source>Restore Defaults</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="97"/>
        <source>Scroll between input methods</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="127"/>
        <source>Turn on or off input methods</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="131"/>
        <source>Please enter a new shortcut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="156"/>
        <source>It turns on or off the currently used input method.If no input method is being used or the first input method is not the keyboard, it switches between the first input method and the currently used keyboard/input method.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>fcitx5configtool</name>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="8"/>
        <source>Input Methods</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="9"/>
        <source>Input method management, input method shortcuts, advanced settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> deepin-fcitx5configtool-plugin_6.0.13.tar.xz: BUILD/src/dcc-fcitx5configtool/translations/fcitx5configtool_zh_TW.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_TW">
<context>
    <name>AddonsPage</name>
    <message>
        <location filename="../qml/AddonsPage.qml" line="20"/>
        <source>Add-ons</source>
        <translation>附加元件</translation>
    </message>
</context>
<context>
    <name>AdvancedSettingsModule</name>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="14"/>
        <source>Advanced Settings</source>
        <translation>高級設定</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="28"/>
        <source>&quot;Advanced Settings&quot; is only valid for the input method that uses the system settings, if the input method has its own settings, its own settings shall prevail.</source>
        <translation>「高級設定」僅針對使用系統設定的輸入法生效，若輸入法有自身的設定則以自身設定為準。</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="41"/>
        <source>Global Config</source>
        <translation>全域性配置</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="52"/>
        <source>Add-ons</source>
        <translation>附加元件</translation>
    </message>
</context>
<context>
    <name>DetailConfigItem</name>
    <message>
        <location filename="../qml/DetailConfigItem.qml" line="126"/>
        <source>Please enter a new shortcut</source>
        <translation>請輸入新的快捷鍵</translation>
    </message>
</context>
<context>
    <name>IMList</name>
    <message>
        <location filename="../qml/IMList.qml" line="54"/>
        <source>Move Up</source>
        <translation>上移</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="61"/>
        <source>Move Down</source>
        <translation>下移</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="69"/>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="76"/>
        <source>Remove</source>
        <translation>刪除</translation>
    </message>
</context>
<context>
    <name>InputMethodsChooser</name>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="29"/>
        <source>Add input method</source>
        <translation>新增輸入法</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="37"/>
        <source>Search</source>
        <translation>搜尋</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="102"/>
        <source>Find more in App Store</source>
        <translation>前往商店下載</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="121"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="128"/>
        <source>Add</source>
        <translation>新增</translation>
    </message>
</context>
<context>
    <name>ManageInputMethodsModule</name>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="15"/>
        <source>Input method management</source>
        <translation>輸入法管理</translation>
    </message>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="29"/>
        <source>Add input method</source>
        <translation>新增輸入法</translation>
    </message>
</context>
<context>
    <name>ShortcutsModule</name>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="34"/>
        <source>Shortcuts</source>
        <translation>快捷鍵</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="45"/>
        <source>Restore Defaults</source>
        <translation>恢復預設</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="97"/>
        <source>Scroll between input methods</source>
        <translation>輪序切換輸入法</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="127"/>
        <source>Turn on or off input methods</source>
        <translation>開啟/關閉輸入法</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="131"/>
        <source>Please enter a new shortcut</source>
        <translation>請輸入新的快捷鍵</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="156"/>
        <source>It turns on or off the currently used input method.If no input method is being used or the first input method is not the keyboard, it switches between the first input method and the currently used keyboard/input method.</source>
        <translation>開啟/關閉當前使用的輸入法，如果當前未使用輸入法或者第一位輸入法不是鍵盤，則會在當前使用的鍵盤/輸入法和第一位輸入法之間切換。</translation>
    </message>
</context>
<context>
    <name>fcitx5configtool</name>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="8"/>
        <source>Input Methods</source>
        <translation>輸入法</translation>
    </message>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="9"/>
        <source>Input method management, input method shortcuts, advanced settings</source>
        <translation>輸入法管理、輸入法快捷鍵、高級設定</translation>
    </message>
</context>
</TS>
